==> huaweicloudsdkrds-3.1.46-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/modify_collation_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ModifyCollationRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'collation': 'str'
    }

    attribute_map = {
        'collation': 'collation'
    }

    def __init__(self, collation=None):
        """ModifyCollationRequestBody

        The model defined in huaweicloud sdk

        :param collation: 字符集。 取值范围：根据查询SQL Server可用字符集查询可设置的字符集。
        :type collation: str
        """
        
        

        self._collation = None
        self.discriminator = None

        self.collation = collation

    @property
    def collation(self):
        """Gets the collation of this ModifyCollationRequestBody.

        字符集。 取值范围：根据查询SQL Server可用字符集查询可设置的字符集。

        :return: The collation of this ModifyCollationRequestBody.
        :rtype: str
        """
        return self._collation

    @collation.setter
    def collation(self, collation):
        """Sets the collation of this ModifyCollationRequestBody.

        字符集。 取值范围：根据查询SQL Server可用字符集查询可设置的字符集。

        :param collation: The collation of this ModifyCollationRequestBody.
        :type collation: str
        """
        self._collation = collation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModifyCollationRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.1.152-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/modify_collation_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ModifyCollationRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'collation': 'str'
    }

    attribute_map = {
        'collation': 'collation'
    }

    def __init__(self, collation=None):
        r"""ModifyCollationRequestBody

        The model defined in huaweicloud sdk

        :param collation: 字符集。 取值范围：根据查询SQL Server可用字符集查询可设置的字符集。
        :type collation: str
        """
        
        

        self._collation = None
        self.discriminator = None

        self.collation = collation

    @property
    def collation(self):
        r"""Gets the collation of this ModifyCollationRequestBody.

        字符集。 取值范围：根据查询SQL Server可用字符集查询可设置的字符集。

        :return: The collation of this ModifyCollationRequestBody.
        :rtype: str
        """
        return self._collation

    @collation.setter
    def collation(self, collation):
        r"""Sets the collation of this ModifyCollationRequestBody.

        字符集。 取值范围：根据查询SQL Server可用字符集查询可设置的字符集。

        :param collation: The collation of this ModifyCollationRequestBody.
        :type collation: str
        """
        self._collation = collation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModifyCollationRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
